# glasswool

Outlier filter

[![Pyversions](https://img.shields.io/pypi/pyversions/linkml.svg)](https://pypi.python.org/pypi/linkml)
[![PyPI](https://img.shields.io/pypi/v/glasswool.svg)](https://pypi.org/project/glasswool)
![](https://github.com/banditSC86/glasswool/workflows/Build/badge.svg)
[![Build status](https://github.com/banditSC86/glasswool/actions/workflows/glasswool-main.yml/badge.svg)](https://github.com/banditSC86/glasswool/actions/workflows/glasswool-main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/banditSC86/glasswool/branch/main/graph/badge.svg?token=WNQNG986UN)](https://codecov.io/gh/banditSC86/glasswool)


Recursively filter outliers 

## Installation

```pip install glasswool```

